import * as elements from "@yellicode/elements";
/**
 * Defines the interface for classes that create type names for types in a model.
 * This interface is implemented by the DefaultTypeNameProvider, which can be extended
 * to provide language-specific type names.
 */
export interface TypeNameProvider {
    /**
     * Gets the name of the typed type. If the name could not be determined, this function returns null.
     */
    getTypeName(type: elements.Type): string | null;
    /**
     * Gets the name of the typed element's type. If the name could not be determined, this function returns null.
     */
    getTypeName(typedElement: elements.TypedElement): string | null;
}
/**
 * Default implementation of the TypeNameProvider interface. This implementation
 * returns type names as-is but allows inheritors to map data types
 * and other types separately.
 */
export declare class DefaultTypeNameProvider implements TypeNameProvider {
    getTypeName(type: elements.Type): string | null;
    getTypeName(typedElement: elements.TypedElement): string | null;
    /**
     * Returns the name of the provided element's data type. Override this function to map primitives and other data types
     * (both built-in or types exported from a profile) to the target language. The default implementation calls the
     * getDataTypeNameForType function using the type of the typedElement.
     * @param typedElement Any TypedElement instance.
     */
    protected getDataTypeName(typedElement: elements.TypedElement): string | null;
    /**
    * Returns the name of the provided data type. Override this function to map primitives and other data types
    * (both built-in or types exported from a profile) to the target language.
    * @param type The type information.
    */
    protected getDataTypeNameForType(type: elements.Type | null): string | null;
    /**
     * Returns the name of the provided element's complex type (any type that is not a DataType). Override this function to provide
     * a custom name for the complex type. The default implementation calls the getComplexTypeNameForType function using
     * the type of the typedElement.
     * @param typedElement Any TypedElement instance.
     */
    protected getComplexTypeName(typedElement: elements.TypedElement): string | null;
    /**
   * Returns the name of the provided complex type (any type that is not a DataType). Override this function to provide
   * a custom name for the complex type.
   * @param type The type information.
   */
    protected getComplexTypeNameForType(type: elements.Type | null): string | null;
}
